@@ -12,7 +12,7 @@ use File::Which ();
 # Globals
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK $IMPLEMENTED_BY};
 BEGIN {
-	$VERSION = '0.94_01';
+	$VERSION = '0.96_01';
 
 	# Inherit manually
 	require Exporter;
@@ -382,10 +382,11 @@ that exported a C<home()> function by default and tied the C<%~> variable.
 It is generally not recommended that you use this interface, but due to
 back-compatibility reasons they will remain supported until at least 2010.
 
-The C<%~> interface has been deprecated and is no longer documented. Any
-usage will issue warnings from 2013 and be removed in 2015 (in line with
-the general Perl convention of a 10 year support period for legacy APIs
-potentially or actually in common use).
+The C<%~> interface has been deprecated. Documentation was removed in 2009,
+Unit test were removed in 2011, usage will issue warnings from 2013, and the
+interface will be removed entirely in 2015  (in line with the general Perl
+toolchain convention of a 10 year support period for legacy APIs that
+are potentially or actually in common use).
 
 =head2 Platform Neutrality
 
@@ -708,7 +709,7 @@ L<File::ShareDir>, L<File::HomeDir::Win32> (legacy)
 
 =head1 COPYRIGHT
 
-Copyright 2005 - 2010 Adam Kennedy.
+Copyright 2005 - 2011 Adam Kennedy.
 
 Some parts copyright 2000 Sean M. Burke.
 
@@ -716,7 +717,7 @@ Some parts copyright 2006 Chris Nandor.
 
 Some parts copyright 2006 Stephen Steneker.
 
-Some parts copyright 2009-2010 Jérôme Quelin.
+Some parts copyright 2009-2011 Jérôme Quelin.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
